@@ -13,9 +13,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Public License along with this library; if not, see <http://www.gnu.org/licenses/>.
  *
  * Author: Alexander Larsson <alexl@redhat.com>
  */
@@ -49,12 +47,12 @@ typedef struct _GSimpleAsyncResultClass   GSimpleAsyncResultClass;
 GLIB_AVAILABLE_IN_ALL
 GType               g_simple_async_result_get_type         (void) G_GNUC_CONST;
 
-GLIB_AVAILABLE_IN_ALL
+GLIB_DEPRECATED_IN_2_46_FOR(g_task_new)
 GSimpleAsyncResult *g_simple_async_result_new              (GObject                 *source_object,
 							    GAsyncReadyCallback      callback,
 							    gpointer                 user_data,
 							    gpointer                 source_tag);
-GLIB_AVAILABLE_IN_ALL
+GLIB_DEPRECATED_IN_2_46_FOR(g_task_new)
 GSimpleAsyncResult *g_simple_async_result_new_error        (GObject                 *source_object,
 							    GAsyncReadyCallback      callback,
 							    gpointer                 user_data,
@@ -62,83 +60,83 @@ GSimpleAsyncResult *g_simple_async_result_new_error        (GObject
 							    gint                     code,
 							    const char              *format,
 							    ...) G_GNUC_PRINTF (6, 7);
-GLIB_AVAILABLE_IN_ALL
+GLIB_DEPRECATED_IN_2_46_FOR(g_task_new)
 GSimpleAsyncResult *g_simple_async_result_new_from_error   (GObject                 *source_object,
 							    GAsyncReadyCallback      callback,
 							    gpointer                 user_data,
 							    const GError            *error);
-GLIB_AVAILABLE_IN_ALL
+GLIB_DEPRECATED_IN_2_46_FOR(g_task_new)
 GSimpleAsyncResult *g_simple_async_result_new_take_error   (GObject                 *source_object,
 							    GAsyncReadyCallback      callback,
 							    gpointer                 user_data,
 							    GError                  *error);
 
-GLIB_AVAILABLE_IN_ALL
+GLIB_DEPRECATED_IN_2_46
 void                g_simple_async_result_set_op_res_gpointer (GSimpleAsyncResult      *simple,
                                                                gpointer                 op_res,
                                                                GDestroyNotify           destroy_op_res);
-GLIB_AVAILABLE_IN_ALL
+GLIB_DEPRECATED_IN_2_46
 gpointer            g_simple_async_result_get_op_res_gpointer (GSimpleAsyncResult      *simple);
 
-GLIB_AVAILABLE_IN_ALL
+GLIB_DEPRECATED_IN_2_46
 void                g_simple_async_result_set_op_res_gssize   (GSimpleAsyncResult      *simple,
                                                                gssize                   op_res);
-GLIB_AVAILABLE_IN_ALL
+GLIB_DEPRECATED_IN_2_46
 gssize              g_simple_async_result_get_op_res_gssize   (GSimpleAsyncResult      *simple);
 
-GLIB_AVAILABLE_IN_ALL
+GLIB_DEPRECATED_IN_2_46
 void                g_simple_async_result_set_op_res_gboolean (GSimpleAsyncResult      *simple,
                                                                gboolean                 op_res);
-GLIB_AVAILABLE_IN_ALL
+GLIB_DEPRECATED_IN_2_46
 gboolean            g_simple_async_result_get_op_res_gboolean (GSimpleAsyncResult      *simple);
 
 
 
-GLIB_AVAILABLE_IN_2_32
+GLIB_AVAILABLE_IN_2_32 /* Also deprecated, but can't mark something both AVAILABLE and DEPRECATED */
 void                g_simple_async_result_set_check_cancellable (GSimpleAsyncResult *simple,
                                                                  GCancellable       *check_cancellable);
-GLIB_AVAILABLE_IN_ALL
+GLIB_DEPRECATED_IN_2_46
 gpointer            g_simple_async_result_get_source_tag   (GSimpleAsyncResult      *simple);
-GLIB_AVAILABLE_IN_ALL
+GLIB_DEPRECATED_IN_2_46
 void                g_simple_async_result_set_handle_cancellation (GSimpleAsyncResult      *simple,
 								   gboolean          handle_cancellation);
-GLIB_AVAILABLE_IN_ALL
+GLIB_DEPRECATED_IN_2_46
 void                g_simple_async_result_complete         (GSimpleAsyncResult      *simple);
-GLIB_AVAILABLE_IN_ALL
+GLIB_DEPRECATED_IN_2_46
 void                g_simple_async_result_complete_in_idle (GSimpleAsyncResult      *simple);
-GLIB_AVAILABLE_IN_ALL
+GLIB_DEPRECATED_IN_2_46
 void                g_simple_async_result_run_in_thread    (GSimpleAsyncResult      *simple,
 							    GSimpleAsyncThreadFunc   func,
 							    int                      io_priority,
 							    GCancellable            *cancellable);
-GLIB_AVAILABLE_IN_ALL
+GLIB_DEPRECATED_IN_2_46
 void                g_simple_async_result_set_from_error   (GSimpleAsyncResult      *simple,
 							    const GError            *error);
-GLIB_AVAILABLE_IN_ALL
+GLIB_DEPRECATED_IN_2_46
 void                g_simple_async_result_take_error       (GSimpleAsyncResult      *simple,
 							    GError            *error);
-GLIB_AVAILABLE_IN_ALL
+GLIB_DEPRECATED_IN_2_46
 gboolean            g_simple_async_result_propagate_error  (GSimpleAsyncResult      *simple,
 							    GError                 **dest);
-GLIB_AVAILABLE_IN_ALL
+GLIB_DEPRECATED_IN_2_46
 void                g_simple_async_result_set_error        (GSimpleAsyncResult      *simple,
 							    GQuark                   domain,
 							    gint                     code,
 							    const char              *format,
 							    ...) G_GNUC_PRINTF (4, 5);
-GLIB_AVAILABLE_IN_ALL
+GLIB_DEPRECATED_IN_2_46
 void                g_simple_async_result_set_error_va     (GSimpleAsyncResult      *simple,
 							    GQuark                   domain,
 							    gint                     code,
 							    const char              *format,
 							    va_list                  args)
 							    G_GNUC_PRINTF(4, 0);
-GLIB_AVAILABLE_IN_ALL
+GLIB_DEPRECATED_IN_2_46
 gboolean            g_simple_async_result_is_valid         (GAsyncResult            *result,
                                                             GObject                 *source,
                                                             gpointer                 source_tag);
 
-GLIB_AVAILABLE_IN_ALL
+GLIB_DEPRECATED_IN_2_46_FOR(g_task_report_error)
 void g_simple_async_report_error_in_idle  (GObject            *object,
 					   GAsyncReadyCallback callback,
 					   gpointer            user_data,
@@ -146,12 +144,12 @@ void g_simple_async_report_error_in_idle  (GObject            *object,
 					   gint                code,
 					   const char         *format,
 					   ...) G_GNUC_PRINTF(6, 7);
-GLIB_AVAILABLE_IN_ALL
+GLIB_DEPRECATED_IN_2_46_FOR(g_task_report_error)
 void g_simple_async_report_gerror_in_idle (GObject            *object,
 					   GAsyncReadyCallback callback,
 					   gpointer            user_data,
 					   const GError       *error);
-GLIB_AVAILABLE_IN_ALL
+GLIB_DEPRECATED_IN_2_46_FOR(g_task_report_error)
 void g_simple_async_report_take_gerror_in_idle (GObject            *object,
                                                 GAsyncReadyCallback callback,
                                                 gpointer            user_data,
